# ubuntuone.tests.platform.notification - Test User Notification
#
# Author: Eric Casteleijn <eric.casteleijn@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Module that implements notification of the end user."""

from twisted.trial.unittest import TestCase

from ubuntuone.status.notification import AbstractNotification

APPLICATION_NAME = 'Ubuntu One Tests'
TEST_TITLE = 'This is the Title'
TEST_MESSAGE = 'This is the body of the message.'
TEST_MESSAGE2 = 'This is the body of the second message.'


class FakeNotification(AbstractNotification):
    """A fake implementation of a notify class."""

    def __init__(self, application_name=APPLICATION_NAME):
        self.application_name = application_name
        self.notifications = []

    def send_notification(self, title, message, icon=None, append=False):
        """Fake sending a notification."""
        self.notifications.append((title, message, icon, append))


class TestNotification(TestCase):
    """Notification of the end user."""

    def setUp(self):
        self.notification = FakeNotification()

    def test_notifications(self):
        """Test the notification."""
        self.notification.send_notification(
            TEST_TITLE, TEST_MESSAGE, append=True)
        self.notification.send_notification(
            TEST_TITLE, TEST_MESSAGE2, append=True)
        self.assertEqual(
            [(TEST_TITLE, TEST_MESSAGE, None, True),
             (TEST_TITLE, TEST_MESSAGE2, None, True)],
            self.notification.notifications)
