# ubuntuone.syncdaemon.status_listener
#
# Author: Alejandro J. Cura <alecu@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Listener for event queue that updates the UI to show syncdaemon status."""

from ubuntuone.status.aggregator import StatusAggregator

def should_start_listener():
    """Check if the status listener should be started."""
    # TODO: look this up in some configuration object
    return True

def get_listener(fsm, vm):
    """Return an instance of the status listener, or None if turned off."""
    if should_start_listener():
        aggregator = StatusAggregator()
        return StatusListener(fsm, vm, aggregator)
    else:
        return None

class StatusListener(object):
    """SD listener for EQ events that turns them into status updates."""

    def __init__(self, fsm, vm, aggregator):
        """Initialize this instance with the FSM and VM."""
        self.fsm = fsm
        self.vm = vm
        self.aggregator = aggregator

    def handle_AQ_CHANGE_PUBLIC_ACCESS_OK(self, share_id, node_id, is_public,
                                                  public_url):
        """The status of a published resource changed."""
        if is_public:
            self.aggregator.file_published(public_url)
        else:
            self.aggregator.file_unpublished(public_url)
